@@ -83,4 +83,10 @@ def coffeescript(path):
             compiled_file.write(out)
             compiled_file.close()
 
+            # Remove old files
+            compiled_filename = os.path.split(output_path)[-1]
+            for filename in os.listdir(output_directory):
+                if filename.startswith(base_filename) and filename != compiled_filename:
+                    os.remove(os.path.join(output_directory, filename))
+
     return output_path[len(settings.MEDIA_ROOT):].lstrip("/")
